enum PlanetType {
  GAS_GIANT, NEPTUNE_LIKE, SUPER_EARTH, TERRESTRIAL
}

class Exoplanet {
    String name;
    int discoveryYear;
    float stellarMagnitude, distance, orbital_radius, orbital_period,eccentricity;
    PlanetType planetType;
    String radius_wrt;
    float radius_multiplier;

    Exoplanet(String name, int discoveryYear, float stellarMagnitude, float distance,String typeString, float orbital_radius,float orbital_period,float eccentricity, String radius_wrt, float radius_multiplier) {
        this.name = name;
        this.discoveryYear = discoveryYear;
        this.stellarMagnitude = stellarMagnitude;
        this.distance = distance;
        this.planetType = convertPlanetType(typeString);
        this.orbital_radius = orbital_radius;
        this.orbital_period = orbital_period;
        this.eccentricity = eccentricity;
        this.radius_wrt = radius_wrt;
        this.radius_multiplier = radius_multiplier;
        // Update global min/max as needed
        minYear = min(minYear, discoveryYear);
        maxYear = max(maxYear, discoveryYear);
        minMagnitude = min(minMagnitude, stellarMagnitude);
        maxMagnitude = max(maxMagnitude, stellarMagnitude);
        minDistance = min(minDistance, distance);
        maxDistance = max(maxDistance, distance);
    }
}

PlanetType convertPlanetType(String typeString) {
    if (typeString.equals("Gas Giant")) {
      return PlanetType.GAS_GIANT;
    } else if (typeString.equals("Neptune-like")) {
      return PlanetType.NEPTUNE_LIKE;
    } else if (typeString.equals("Super Earth")) {
      return PlanetType.SUPER_EARTH;
    } else if (typeString.equals("Terrestrial")) {
      return PlanetType.TERRESTRIAL;
    } else {
      return null; // Or some default value
    }
  }
  
color getColorForPlanetType(PlanetType planetType) {
  switch (planetType) {
    case GAS_GIANT:
      return color(225, 200, 190, 100); //color for GAS_GIANT
    case NEPTUNE_LIKE:
      return color(75, 110, 245); //color for NEPTUNE_LIKE
    case SUPER_EARTH:
      return color(160, 190, 170); //color for SUPER_EARTH
    case TERRESTRIAL:
      return color(200, 145, 60); //color for TERRESTRIAL
    default:
      return color(255); // Default white color
  }
}
         
Exoplanet convertCSVRowToExoplanet(String[] row) {
  try {
    String name = row[0];
    int discoveryYear = Integer.parseInt(row[1]);
    float stellarMagnitude = Float.parseFloat(row[2]);
    float distance = Float.parseFloat(row[3]);
    String typeString = row[4];
    float orbital_radius = Float.parseFloat(row[5]);
    float orbital_period = Float.parseFloat(row[6]);  
    float eccentricity = Float.parseFloat(row[7]);    
    String radius_wrt = row[8];
    float radius_multiplier = Float.parseFloat(row[9]);

    return new Exoplanet(name, discoveryYear, stellarMagnitude, distance, typeString,orbital_radius,orbital_period,eccentricity,radius_wrt,radius_multiplier);
  } catch (NumberFormatException e) {
    // Handle the case where the row has invalid data
    println("Error parsing CSV row: " + e.getMessage());
    return null;
  }
}
