void drawYearCircle(int minYear, int maxYear, float radius) {
    // Draw the year circle
    beginShape();
    strokeWeight(2);
    stroke(255); // Red color for the year circle
    noFill();
    for (int year = minYear; year <= maxYear; year++) {
        float theta = map(year, minYear, maxYear, 0, TWO_PI);
        float x = radius * cos(theta);
        float y = radius * sin(theta);
        vertex(x, y, 0);
    }
    endShape(CLOSE);
    
    // Draw year labels
    textAlign(CENTER, CENTER);
    fill(255); // White color for the text
    textSize(45); // Adjust text size as needed
    int labelInterval = 1; // For example, label every 5 years. Adjust based on your year range
    for (int year = minYear; year <= maxYear; year += labelInterval) {
        float theta = map(year, minYear, maxYear, 0, TWO_PI);
        // Position the text slightly outside the circle radius
        float labelRadius = radius + 50; // Adjust the offset as needed
        float x = labelRadius * cos(theta);
        float y = labelRadius * sin(theta);
        text(year, x, y);
    }
}

void drawMagnitudeCircle(float minMagnitude, float maxMagnitude, float radius) {
    beginShape();
    strokeWeight(2);
    stroke(255); // Different color for distinction
    noFill();
    for (float mag = minMagnitude; mag <= maxMagnitude; mag += (maxMagnitude - minMagnitude) / 360.0) {
        float theta = map(mag, minMagnitude, maxMagnitude, 0, TWO_PI);
        float x = radius * cos(theta);
        float z = radius * sin(theta); // Note the use of Z instead of Y
        vertex(x, 0, z); // Adjust accordingly for the XZ plane
    }
    endShape(CLOSE);

    textAlign(CENTER, RIGHT);
    fill(255); // White color for the text
    textSize(40); // Adjust text size as needed
    int labelInterval2 = 1; // For example, label every 5 years. Adjust based on your year range
    for (float mag = minMagnitude; mag <= maxMagnitude; mag += labelInterval2) {
        float theta = map(mag, minMagnitude, maxMagnitude, 0, TWO_PI);
        // Position the text slightly outside the circle radius
        float labelRadius = radius + 50; // Adjust the offset as needed
        float x = labelRadius * cos(theta);
        float z = labelRadius * sin(theta);
        
        pushMatrix();
        translate(x,0,z);
        
        rotateY(-theta);
        text(Float.toString(mag), 0,0);
        popMatrix();
    }
}


void drawDistanceCircle(float minDistance, float maxDistance, float radius) {
    beginShape();
    stroke(255);
    strokeWeight(2);
    noFill();
    for (float dist = minDistance; dist <= maxDistance; dist += (maxDistance - minDistance) / 360.0) {
        float theta = map(dist, minDistance, maxDistance, 0, TWO_PI);
        float y = radius * cos(theta);
        float z = radius * sin(theta); // YZ plane
        vertex(0, y, z); // Adjust accordingly for the YZ plane
    }
    endShape(CLOSE);
    
    textAlign(CENTER, CENTER);
    fill(255); // White color for the text
    textSize(40); // Adjust text size as needed
    float labelInterval = (maxDistance - minDistance) / 10; // Adjust based on your range
    for (float dist = minDistance; dist <= maxDistance; dist += labelInterval) {
        float theta = map(dist, minDistance, maxDistance, 0, TWO_PI);
        // Position the text slightly outside the circle radius for clear visibility
        float labelRadius = radius + 50; // Adjust the offset as needed
        float y = labelRadius * cos(theta);
        float z = labelRadius * sin(theta);
        
        pushMatrix();
        translate(0, y, z);

        // For YZ plane text to face the camera directly without upside-down or mirrored effect,
        rotateX(PI / 2); // Rotate the text to face outwards from the YZ plane
        //rotateY(-theta + PI); // Adjust so text faces the viewer, adding PI to flip right way up

        text(Float.toString(dist), 0,0);
        popMatrix();
    }    
}

void setGui() {
  PFont fontSmall = createFont("Century Gothic", 14, true);
  PFont fontLarge = createFont("Bauhaus 93", 30, true);
  float X = width; //x position for gui elements
  float distance = 50; //vertical spacing between gui elements
      
  cp5.addSlider("currentYearFilter")
    .setPosition(X/2 -900, 850)
    .setFont(fontSmall)
    .setWidth(200)
    .setHeight(50)
    .setRange(1992, 2023)
    .setValue(2023)
    .setColorActive(color(100))//active
    .setColorForeground(color(100)) 
    .setColorBackground(color(50)) //not active
    .plugTo(this,"currentYearFilter")
    .setLabel("Year Filter");
    
    
  cp5.addToggle("showGasGiant")
    .setSize(50,20)
    .setValue(showGasGiant)
    .setPosition(X/2 - 900, 1000)
    .setFont(fontSmall)     
    .plugTo(this, "showGasGiant")    
    .setColorActive(color(225, 200, 190, 100))//active
    .setColorForeground(color(225, 200, 190, 100))
    .setColorBackground(color(50)) //not active
    .setLabel("Gas Giant"); 
    
 cp5.addToggle("showNeptuneLike")
        .setSize(50, 20)
        .setValue(showNeptuneLike)
        .setPosition(X/2 - 900, 925)
        .setFont(fontSmall)
        .setColorActive(color(75, 110, 245))//active
        .setColorForeground(color(75, 110, 245))
        .setColorBackground(color(50)) //not active        
        .plugTo(this, "showNeptuneLike")
        .setLabel("Neptune-like");

    cp5.addToggle("showSuperEarth")
        .setSize(50, 20)
        .setValue(showSuperEarth)
        .setPosition(X/2 - 800, 925)
        .setFont(fontSmall)
        .setColorActive(color(160, 190, 170))//active
        .setColorForeground(color(160, 190, 170)) 
        .setColorBackground(color(50)) //not active
        .plugTo(this, "showSuperEarth")
        .setLabel("Super-Earth");

    cp5.addToggle("showTerrestrial")
        .setSize(50, 20)
        .setValue(showTerrestrial)
        .setPosition(X/2 - 800, 1000) 
        .setFont(fontSmall)
        .setColorActive(color(200, 145, 60))//not active
        .setColorForeground(color(200, 145, 60))
        .setColorBackground(color(50)) // active
        .plugTo(this, "showTerrestrial")
        .setLabel("Terrestrial");
        
  cp5.addButton("toggleOrbits")
   .setPosition(X/2 - 900, 800) 
   .setSize(200, 20)
   .setFont(fontSmall)
   .setColorActive(color(50))//active
   .setColorForeground(color(155)) // on click
   .setColorBackground(color(50)) //not active
   .setLabel("Show Orbits")
   .onClick(new CallbackListener() {
     public void controlEvent(CallbackEvent event) {
       showOrbits = !showOrbits; 
     }
   });
   
  cp5.addButton("Show Curves")
   .setPosition(X/2 - 900, 775) // Adjust position as needed
   .setSize(200, 20)
   .setFont(fontSmall)
   .setColorActive(color(50))//active
   .setColorForeground(color(155)) // on click
   .setColorBackground(color(50)) //not active
   .setLabel("Curves")
   .onClick(new CallbackListener() {
     public void controlEvent(CallbackEvent event) {
       showCurves = !showCurves; // Toggle visibility
     }
   });
      
  cp5.addTextlabel("dynamicYear")
  .setFont(new ControlFont(fontSmall))
  .setValue("")
  .setColorValue(color(255,255,255))
  .setPosition(X/2 - 500, distance);
  
  cp5.addTextlabel("dynamicDistance")
  .setFont(new ControlFont(fontSmall))
  .setValue("")
  .setColorValue(color(255,255,255))
  .setPosition(X/2 - 500, distance + 40);
    
  cp5.addTextlabel("dynamicName")
  .setFont(new ControlFont(fontSmall))
  .setText("")
  .setColorValue(color(255,255,255))
  .setPosition(X/2 - 500, distance +20);
  
  
  cp5.addTextlabel("mainTitle")
  .setFont(new ControlFont(fontLarge))
  .setText("Outer Rim Territories")
  .setColorValue(color(255,255,255))
  .setPosition( X/2 -900 , distance);
      
  cp5.setAutoDraw(false);
}

void gui(){
  hint(DISABLE_DEPTH_TEST);
  cam.beginHUD(); 
  
  float rectWidth = width; // Width Backgroud Rect
  float rectHeight = 140;  // Height Background Rect
  float rectX = width / 2 - rectWidth / 2; // Center the rectangle
  float rectY = 0; 
  fill(0); 
  noStroke();
  rect(rectX, rectY, rectWidth, rectHeight);
  
  cp5.draw();
  cam.endHUD();
  hint(ENABLE_DEPTH_TEST);
}
